@@ -616,7 +616,6 @@ process_component_from_server (CalBackendWCAP *wcap, ECalComponent *comp)
 	ECalComponentDateTime dt_start, dt_end;
 	ECalComponentOrganizer organizer;
 	GSList *attendee_list, *l;
-	icaltimezone *izone = NULL;
 	
 	icalcomp = e_cal_component_get_icalcomponent (comp);
 
@@ -626,42 +625,23 @@ process_component_from_server (CalBackendWCAP *wcap, ECalComponent *comp)
 		icalcomponent_remove_property (icalcomp, prop);
 
 	/* Put everything in the right timezone */
-	prop = icalcomponent_get_first_property (icalcomp, ICAL_X_PROPERTY);
-	while (prop) {
-		const char *x_name, *x_val;
-
-		x_name = icalproperty_get_x_name (prop);
-		x_val = icalproperty_get_x (prop);
-
-		if (!strcmp (x_name, "X-NSCP-DTSTART-TZID")
-		    || !strcmp (x_name, "X-NSCP-DUE-TZID")) {
-			izone = cal_backend_wcap_get_timezone_from_tzid (wcap, x_val, TRUE);
-			break;			
-		}
-
-		prop = icalcomponent_get_next_property (icalcomp, ICAL_X_PROPERTY);
-	}
-
-	if (!izone)
-		izone = priv->server_default_zone;
-	
-	if (izone) {
+	if (priv->default_zone) {
 		ECalComponentDateTime dt;
 		icaltimezone *utc_zone;
 		icaltimezone *local_zone;
 
-		local_zone = icaltimezone_get_builtin_timezone (icaltimezone_get_location (izone));
+		local_zone = icaltimezone_get_builtin_timezone (icaltimezone_get_location (priv->default_zone));
 
 		utc_zone = icaltimezone_get_utc_timezone ();
 
 		e_cal_component_get_dtstart (comp, &dt);
 		if (dt.value && !icaltime_is_null_time (*dt.value)) {
-			icaltimezone_convert_time (dt.value, utc_zone, izone);
+			icaltimezone_convert_time (dt.value, utc_zone, priv->default_zone);
 			g_free ((char *)dt.tzid);
 			if (local_zone) {
 				dt.tzid = g_strdup (icaltimezone_get_tzid (local_zone));
 			} else  {
-				dt.tzid = g_strdup (icaltimezone_get_tzid (izone));
+				dt.tzid = g_strdup (icaltimezone_get_tzid (priv->default_zone));
 			}
 			e_cal_component_set_dtstart (comp, &dt);
 		}
@@ -669,12 +649,12 @@ process_component_from_server (CalBackendWCAP *wcap, ECalComponent *comp)
 		
 		e_cal_component_get_dtend (comp, &dt);
 		if (dt.value && !icaltime_is_null_time (*dt.value)) {
-			icaltimezone_convert_time (dt.value, utc_zone, izone);
+			icaltimezone_convert_time (dt.value, utc_zone, priv->default_zone);
 			g_free ((char *)dt.tzid);
 			if (local_zone) {
 				dt.tzid = g_strdup (icaltimezone_get_tzid (local_zone));
 			} else {
-				dt.tzid = g_strdup (icaltimezone_get_tzid (izone));
+				dt.tzid = g_strdup (icaltimezone_get_tzid (priv->default_zone));
 			}
 			e_cal_component_set_dtend (comp, &dt);
 		}
@@ -682,12 +662,12 @@ process_component_from_server (CalBackendWCAP *wcap, ECalComponent *comp)
 		
 		e_cal_component_get_due (comp, &dt);
 		if (dt.value && !icaltime_is_null_time (*dt.value)) {
-			icaltimezone_convert_time (dt.value, utc_zone, izone);
+			icaltimezone_convert_time (dt.value, utc_zone, priv->default_zone);
 			g_free ((char *)dt.tzid);
 			if (local_zone)
 				dt.tzid = g_strdup (icaltimezone_get_tzid (local_zone));
 			else 
-				dt.tzid = g_strdup (icaltimezone_get_tzid (izone));
+				dt.tzid = g_strdup (icaltimezone_get_tzid (priv->default_zone));
 			e_cal_component_set_due (comp, &dt);
 		}
 		e_cal_component_free_datetime (&dt);
@@ -704,8 +684,8 @@ process_component_from_server (CalBackendWCAP *wcap, ECalComponent *comp)
 			
 			ex = l->data;
 			/* convert from utc zone to local zone */
-			if (izone) {
-				icaltimezone_convert_time (ex->value, icaltimezone_get_utc_timezone(), izone);
+			if (priv->default_zone) {
+				icaltimezone_convert_time (ex->value, icaltimezone_get_utc_timezone(), priv->default_zone);
 				ex->value->is_utc = FALSE;
 			}
 
